﻿#requires -version 3.0

Function Get-IPConfigDNS {
[cmdletbinding()]
Param()

Write-Verbose "Getting DNS cache information"

#parse dns data looking only for "Record" followed by a space
#and the Time to live line
$data = ipconfig /displaydns | select-string "Record |Time"
Write-Verbose ("Retrieved {0} entries" -f $data.count)
Write-Verbose ("There should be {0} dns records" -f ($data.count/4))

#should be grouped into 4s.
for ($i=0;$i -lt $data.count;$i+=4) {
    Write-Verbose $data[$i]
    
    <#
     each item is a MatchInfo object so convert to string, split at colon,
     grab the last item and trim it up. Cast the Type as an integer
     so it sorts properly.

     [ordered] is a v3 feature. Remove it if you want this to run in
     PowerShell v2
    #>
    
    $hash = [ordered]@{
      Name = $data[$i].toString().Split(":")[1].Trim()
      Type = ($data[$i+1].toString().Split(":")[1].Trim()) -as [int]
      TTL =  ($data[$i+2].toString().Split(":")[1].Trim()) -as [int]
      Address = $data[$i+3].toString().Split(":")[1].Trim()
    }
  
    $obj = New-Object -TypeName PSobject -Property $hash
    #add a method to the object to ping the name
    $obj | Add-Member -MemberType ScriptMethod -Name "Ping" -Value {Test-Connection $this.Name} 
    $obj | Add-Member -MemberType ScriptMethod -Name "Trace" -Value {tracert $this.address} 
    write $obj
} #for

  Write-Verbose "Finished parsing DNS cache data"
} #end function
